Missing Use Cases
=================

"ContentCreator":doc:`Actor_ContentCreator`
-------------------------------------------

* "Define content metadata":doc:ChangeMetadata`

* "Make a content object discussable":doc:`EnableDiscussion`

"MembershipManager":doc:`Actor_MembershipManager`
-------------------------------------------------

* "Add a new member to the site using a standard user
   folder":doc:`AddMemberToUserFolder`

* "Change member information and abilities":doc:`ChangeMemberInformation`

* "Browse member roster":doc:`BrowseMemberRoster`

* "Remove a member from the site":doc:`RemoveMemberFromSite`

"SiteDesigner":docActor_SiteDesigner`
-------------------------------------

* "Create new skin for the site":doc:`CreateNewSkin`

* "Modify skin appearance":doc:`ChangeSkinLookAndFeel`

* "Change skin behavior":doc:`ChangeSkinBehavior`

* "Change the default skin for the site":doc`ChangeDefaultSiteSkin`

"SiteManager":doc:`Actor_SiteManager`
-------------------------------------

* "Configure CMF Topic":ConfigureCMFTopic

* "Configure what types of content can be created by
   users" :doc:`ConfigureAllowedContentTypes`

* "Configure security for a content object or folder":
   :doc:`ConfigureObjectSecurity`

* "Associate a workflow with a content
   type":doc:`AssociateWorkflowWithContentType`

* "Configure required metadata for a content
   type":doc:ConfigureRequiredMetadata`

* "Configure what content is released via
   syndication":doc:`ConfigureContentSyndiation`

"SiteVisitor":Actor_SiteVisitor
-------------------------------

 * "Submit a news item":doc:`SubmitNewsItem`

 * "Browse a portal topic":doc:`BrowsePortalTopic`

